@@ -83,14 +83,6 @@ function date_i18n($dateformatstring, $unixtimestamp) {
 	return $j;
 }
 
-function number_format_i18n($number, $decimals = null) {
-	global $wp_locale;
-	// let the user override the precision only
-	$decimals = is_null($decimals)? $wp_locale->number_format['decimals'] : intval($decimals);
-
-	return number_format($number, $decimals, $wp_locale->number_format['decimal_point'], $wp_locale->number_format['thousands_sep']);
-}
-
 function get_weekstartend($mysqlstring, $start_of_week) {
 	$my = substr($mysqlstring,0,4);
 	$mm = substr($mysqlstring,8,2);
@@ -211,6 +203,7 @@ function is_serialized_string($data) {
 
 /* Options functions */
 
+// expects $setting to already be SQL-escaped
 function get_option($setting) {
 	global $wpdb, $switched, $current_blog;
 
@@ -246,7 +239,7 @@ function get_option($setting) {
 
 			if( is_object( $row) ) { // Has to be get_row instead of get_var because of funkiness with 0, false, null values
 				$value = $row->option_value;
-				wp_cache_set($setting, $value, 'options');
+				wp_cache_add($setting, $value, 'options');
 			} else { // option does not exist, so we must cache its non-existence
 				$notoptions[$setting] = true;
 				wp_cache_set('notoptions', $notoptions, 'options');
@@ -314,21 +307,24 @@ function wp_load_alloptions() {
 		$alloptions = array();
 		foreach ( (array) $alloptions_db as $o )
 			$alloptions[$o->option_name] = $o->option_value;
-		wp_cache_set('alloptions', $alloptions, 'options');
+		wp_cache_add('alloptions', $alloptions, 'options');
 	}
 	return $alloptions;
 }
 
+// expects $option_name to NOT be SQL-escaped
 function update_option($option_name, $newvalue) {
 	global $wpdb;
 
 	wp_protect_special_option($option_name);
 
+	$safe_option_name = $wpdb->escape($option_name);
+
 	if ( is_string($newvalue) )
 		$newvalue = trim($newvalue);
 
 	// If the new and old values are the same, no need to update.
-	$oldvalue = get_option($option_name);
+	$oldvalue = get_option($safe_option_name);
 	if ( $newvalue === $oldvalue ) {
 		return false;
 	}
@@ -366,21 +362,21 @@ function update_option($option_name, $newvalue) {
 }
 
 // thx Alex Stapleton, http://alex.vort-x.net/blog/
+// expects $name to NOT be SQL-escaped
 function add_option($name, $value = '', $description = '', $autoload = 'yes') {
 	global $wpdb;
 
 	wp_protect_special_option($name);
+	$safe_name = $wpdb->escape($name);
 
-	// Make sure the option doesn't already exist we can check the cache before we ask for a db query
+	// Make sure the option doesn't already exist. We can check the 'notoptions' cache before we ask for a db query
 	$notoptions = wp_cache_get('notoptions', 'options');
-	if ( is_array($notoptions) && isset($notoptions[$name]) ) {
-		unset($notoptions[$name]);
-		wp_cache_set('notoptions', $notoptions, 'options');
-	} elseif ( false !== get_option($name) ) {
+	if ( !is_array($notoptions) || !isset($notoptions[$name]) )
+		if ( false !== get_option($safe_name) )
 			return;
-	}
 
 	$value = maybe_serialize($value);
+	$autoload = ( 'no' === $autoload ) ? 'no' : 'yes';
 
 	if ( 'yes' == $autoload ) {
 		$alloptions = wp_load_alloptions();
@@ -390,6 +386,13 @@ function add_option($name, $value = '', $description = '', $autoload = 'yes') {
 		wp_cache_set($name, $value, 'options');
 	}
 
+	// This option exists now
+	$notoptions = wp_cache_get('notoptions', 'options'); // yes, again... we need it to be fresh
+	if ( is_array($notoptions) && isset($notoptions[$name]) ) {
+		unset($notoptions[$name]);
+		wp_cache_set('notoptions', $notoptions, 'options');
+	}
+
 	$name = $wpdb->escape($name);
 	$value = $wpdb->escape($value);
 	$description = $wpdb->escape($description);
@@ -405,14 +408,7 @@ function delete_option($name) {
 
 	// Get the ID, if no ID then return
 	$option = $wpdb->get_row("SELECT option_id, autoload FROM $wpdb->options WHERE option_name = '$name'");
-	if ( !$option->option_id ) {
-		$alloptions = wp_load_alloptions();
-		if ( isset($alloptions[$name]) ) {
-			unset($alloptions[$name]);
-			wp_cache_set('alloptions', $alloptions, 'options');
-		}
-		return false;
-	}
+	if ( !$option->option_id ) return false;
 	$wpdb->query("DELETE FROM $wpdb->options WHERE option_name = '$name'");
 	if ( 'yes' == $option->autoload ) {
 		$alloptions = wp_load_alloptions();
@@ -420,10 +416,9 @@ function delete_option($name) {
 			unset($alloptions[$name]);
 			wp_cache_set('alloptions', $alloptions, 'options');
 		}
+	} else {
+		wp_cache_delete($name, 'options');
 	}
-
-	wp_cache_delete($name, 'options');
-
 	return true;
 }
 
@@ -786,12 +781,12 @@ add_query_arg(associative_array, oldquery_or_uri)
 function add_query_arg() {
 	$ret = '';
 	if ( is_array(func_get_arg(0)) ) {
-		if ( @func_num_args() < 2 || '' == @func_get_arg(1) )
+		if ( @func_num_args() < 2 || false === @func_get_arg(1) )
 			$uri = $_SERVER['REQUEST_URI'];
 		else
 			$uri = @func_get_arg(1);
 	} else {
-		if ( @func_num_args() < 3 || '' == @func_get_arg(2) )
+		if ( @func_num_args() < 3 || false === @func_get_arg(2) )
 			$uri = $_SERVER['REQUEST_URI'];
 		else
 			$uri = @func_get_arg(2);
@@ -826,9 +821,7 @@ function add_query_arg() {
 		$query = $uri;
 	}
 
-	parse_str($query, $qs);
-	if ( get_magic_quotes_gpc() )
-		$qs = stripslashes_deep($qs); // parse_str() adds slashes if magicquotes is on.  See: http://php.net/parse_str
+	wp_parse_str($query, $qs);
 	$qs = urlencode_deep($qs);
 	if ( is_array(func_get_arg(0)) ) {
 		$kayvees = func_get_arg(0);
@@ -849,7 +842,7 @@ function add_query_arg() {
 	}
 	$ret = trim($ret, '?');
 	$ret = $protocol . $base . $ret . $frag;
-	$ret = trim($ret, '?');
+	$ret = rtrim($ret, '?');
 	return $ret;
 }
 
@@ -863,7 +856,7 @@ remove_query_arg(removekey, [oldquery_or_uri]) or
 remove_query_arg(removekeyarray, [oldquery_or_uri])
 */
 
-function remove_query_arg($key, $query='') {
+function remove_query_arg($key, $query=FALSE) {
 	if ( is_array($key) ) { // removing multiple keys
 		foreach ( (array) $key as $k )
 			$query = add_query_arg($k, FALSE, $query);
@@ -926,23 +919,19 @@ function wp($query_vars = '') {
 	$wp->main($query_vars);
 }
 
-function get_status_header_desc( $code ) {
-	global $wp_header_to_desc;
-	
-	$code = (int) $code;
-	
-	if ( isset( $wp_header_to_desc[$code] ) ) {
-		return $wp_header_to_desc[$code];
-	} else {
-		return '';
-	}
-}
-
 function status_header( $header ) {
-	$text = get_status_header_desc( $header );
-	
-	if ( empty( $text ) )
-		return false;
+	if ( 200 == $header )
+		$text = 'OK';
+	elseif ( 301 == $header )
+		$text = 'Moved Permanently';
+	elseif ( 302 == $header )
+		$text = 'Moved Temporarily';
+	elseif ( 304 == $header )
+		$text = 'Not Modified';
+	elseif ( 404 == $header )
+		$text = 'Not Found';
+	elseif ( 410 == $header )
+		$text = 'Gone';
 
 	$protocol = $_SERVER["SERVER_PROTOCOL"];
 	if ( ('HTTP/1.1' != $protocol) && ('HTTP/1.0' != $protocol) )
@@ -1224,7 +1213,6 @@ function wp_check_filetype($filename, $mimes = null) {
 		'js' => 'application/javascript',
 		'pdf' => 'application/pdf',
 		'doc' => 'application/msword',
-		'odt' => 'application/vnd.oasis.opendocument.text',
 		'pot|pps|ppt' => 'application/vnd.ms-powerpoint',
 		'wri' => 'application/vnd.ms-write',
 		'xla|xls|xlt|xlw' => 'application/vnd.ms-excel',
@@ -1512,20 +1500,15 @@ function smilies_init() {
 }
 
 function wp_parse_args( $args, $defaults = '' ) {
-	if ( is_array( $args ) ) {
+	if ( is_array( $args ) )
 		$r =& $args;
-	} else {
-		parse_str( $args, $r );
-		if ( get_magic_quotes_gpc() ) {
-			$r = stripslashes_deep( $r );
-		}
-	}
-	
-	if ( is_array( $defaults ) ) {
+	else
+		wp_parse_str( $args, $r );
+
+	if ( is_array( $defaults ) )
 		return array_merge( $defaults, $r );
-	} else {
+	else
 		return $r;
-	}
 }
 
 function wp_maybe_load_widgets() {
