@@ -218,7 +218,6 @@ if (!CUSTOM_TAGS) {
 		//	'ul' => array(),
 	);
 }
-
 function wp_kses($string, $allowed_html, $allowed_protocols = array ('http', 'https', 'ftp', 'ftps', 'mailto', 'news', 'irc', 'gopher', 'nntp', 'feed', 'telnet'))
 	###############################################################################
 		# This function makes sure that only the allowed HTML element names, attribute
@@ -783,10 +782,13 @@ function kses_remove_filters() {
 
 function wp_filter_post_display_kses($data) {
 	global $allowedposttags;
-	return addslashes( wp_kses(stripslashes( $data ), $allowedtags) );
+	return addslashes( wp_kses(stripslashes( $data ), $allowedposttags) );
 }
 
 function kses_init() {
+	global $allowedposttags, $allowedtags;
+	apply_filters( 'edit_allowedposttags', $allowedposttags );
+	apply_filters( 'edit_allowedtags', $allowedtags );
 	kses_remove_filters();
 
 	kses_init_filters();
